@@ -228,7 +228,7 @@ public:
         size_t src_port,
         const block_id_t& dst_blk,
         size_t dst_port,
-        bool skip_property_propagation) override
+        bool is_back_edge) override
     {
         if (!has_block(src_blk)) {
             throw uhd::lookup_error(
@@ -246,7 +246,7 @@ public:
             get_block(dst_blk),
             dst_port,
             edge_type,
-            skip_property_propagation);
+            is_back_edge);
     }
 
     void disconnect(const block_id_t& src_blk,
@@ -823,10 +823,10 @@ private:
         std::shared_ptr<node_t> dst_blk,
         size_t dst_port,
         graph_edge_t::edge_t edge_type,
-        bool skip_property_propagation)
+        bool is_back_edge)
     {
         graph_edge_t edge_info(
-            src_port, dst_port, edge_type, not skip_property_propagation);
+            src_port, dst_port, edge_type, not is_back_edge);
         edge_info.src_blockid = src_blk->get_unique_id();
         edge_info.dst_blockid = dst_blk->get_unique_id();
         _graph->connect(src_blk.get(), dst_blk.get(), edge_info);
